@@ -13,7 +13,7 @@
 /* |                                                                   | */
 /* +-------------------------------------------------------------------+ */
 
-/* $Id: brushOp.c,v 1.11 1996/11/01 09:37:12 torsten Exp $ */
+/* $Id: brushOp.c,v 1.16 1997/09/03 19:49:52 torsten Exp $ */
 
 #include <X11/Intrinsic.h>
 #include <X11/StringDefs.h>
@@ -232,7 +232,7 @@ release(Widget w, LocalInfo * l, XButtonEvent * event, OpInfo * info)
 static void 
 smear(Widget wid, OpInfo * info, GC gc, LocalInfo * l, int sx, int sy)
 {
-    int x, y, n, xx, yy, w, h, d, m;
+    int x, y, n, dx, dy, w, h, d, m;
     unsigned long r, g, b;
     unsigned char *brushbits;
     Pixel p;
@@ -242,28 +242,30 @@ smear(Widget wid, OpInfo * info, GC gc, LocalInfo * l, int sx, int sy)
     /*
      * Perform manual clipping to avoid XPutImage crashing on us
      */
-    xx = yy = 0;
+    dx = dy = 0;
     w = l->width;
     h = l->height;
+
     if (sx < 0) {
-	xx = -sx;
+	dx = -sx;
 	w += sx;
 	sx = 0;
-    } else if ((d = (sx + w - ((PaintWidget) wid)->paint.drawWidth)) > 0)
+    }
+    if ((d = (sx + w - ((PaintWidget) wid)->paint.drawWidth)) > 0)
 	w -= d;
     if (sy < 0) {
-	yy = -sy;
+	dy = -sy;
 	h += sy;
 	sy = 0;
-    } else if ((d = (sy + h - ((PaintWidget) wid)->paint.drawHeight)) > 0)
+    }
+    if ((d = (sy + h - ((PaintWidget) wid)->paint.drawHeight)) > 0)
 	h -= d;
     if ((w <= 0) || (h <= 0))
 	return;
 
-
     /* copy portion of image under brush into brushImage */
     XGetSubImage(dpy, info->drawable, sx, sy, w, h,
-		 AllPlanes, ZPixmap, brushImage, xx, yy);
+		 AllPlanes, ZPixmap, brushImage, dx, dy);
 
     /* compute average of pixels inside brush */
     r = g = b = 0;
@@ -298,7 +300,7 @@ smear(Widget wid, OpInfo * info, GC gc, LocalInfo * l, int sx, int sy)
 		XPutPixel(brushImage, x, y, p);
 	    }
 	}
-    XPutImage(dpy, info->drawable, gc, brushImage, xx, yy, sx, sy, w, h);
+    XPutImage(dpy, info->drawable, gc, brushImage, dx, dy, sx, sy, w, h);
 }
 
 
@@ -308,7 +310,7 @@ smear(Widget wid, OpInfo * info, GC gc, LocalInfo * l, int sx, int sy)
 static void 
 wbrush(Widget wid, OpInfo * info, GC gc, LocalInfo * l, int sx, int sy)
 {
-    int x, y, xx, yy, m, w, h, d;
+    int x, y, dx, dy, m, w, h, d;
     unsigned long r, g, b;
     unsigned char *brushbits;
     Pixel p;
@@ -320,27 +322,30 @@ wbrush(Widget wid, OpInfo * info, GC gc, LocalInfo * l, int sx, int sy)
     /*
      * Perform manual clipping to avoid XPutImage crashing on us
      */
-    xx = yy = 0;
+    dx = dy = 0;
     w = l->width;
     h = l->height;
+
     if (sx < 0) {
-	xx = -sx;
+	dx = -sx;
 	w += sx;
 	sx = 0;
-    } else if ((d = (sx + w - ((PaintWidget) wid)->paint.drawWidth)) > 0)
+    }
+    if ((d = (sx + w - ((PaintWidget) wid)->paint.drawWidth)) > 0)
 	w -= d;
     if (sy < 0) {
-	yy = -sy;
+	dy = -sy;
 	h += sy;
 	sy = 0;
-    } else if ((d = (sy + h - ((PaintWidget) wid)->paint.drawHeight)) > 0)
+    }
+    if ((d = (sy + h - ((PaintWidget) wid)->paint.drawHeight)) > 0)
 	h -= d;
     if ((w <= 0) || (h <= 0))
 	return;
 
     /* copy portion of image under brush into brushImage */
     XGetSubImage(dpy, info->drawable, sx, sy, w, h,
-		 AllPlanes, ZPixmap, brushImage, xx, yy);
+		 AllPlanes, ZPixmap, brushImage, dx, dy);
 
     /* get current colour */
     XGetGCValues(dpy, gc, GCForeground, &gcval);
@@ -362,7 +367,7 @@ wbrush(Widget wid, OpInfo * info, GC gc, LocalInfo * l, int sx, int sy)
 		p = PaletteAlloc(l->brushPalette, &newcol);
 		XPutPixel(brushImage, x, y, p);
 	    }
-    XPutImage(dpy, info->drawable, gc, brushImage, xx, yy, sx, sy, w, h);
+    XPutImage(dpy, info->drawable, gc, brushImage, dx, dy, sx, sy, w, h);
 }
 
 
@@ -644,6 +649,7 @@ BrushInit(Widget toplevel)
     /* force depth of one */
     xpmAttr.depth = 1;
     xpmAttr.colorsymbols = monoColorSymbols;
+    xpmAttr.numsymbols = 5;
     xpmAttr.valuemask = XpmDepth | XpmColorSymbols;
     XpmCreatePixmapFromData(XtDisplay(toplevel),
 			    RootWindowOfScreen(XtScreen(toplevel)),
@@ -696,10 +702,12 @@ createDialog(Widget w)
     Pixmap pix;
     int nw, nh, ox, oy;
     XpmAttributes xpmAttr;
-
-    shell = XtVaCreatePopupShell("brush",
+    Arg args[3];
+    int nargs = 0;
+    
+    shell = XtVisCreatePopupShell("brush",
 				 topLevelShellWidgetClass, w,
-				 NULL);
+				 args, nargs);
 
     form = XtVaCreateManagedWidget(NULL,
 				   formWidgetClass, shell,
@@ -724,6 +732,7 @@ createDialog(Widget w)
 	    /* force depth of one */
 	    xpmAttr.depth = 1;
 	    xpmAttr.colorsymbols = monoColorSymbols;
+	    xpmAttr.numsymbols = 5;
 	    xpmAttr.valuemask = XpmDepth | XpmColorSymbols;
 	    XpmCreatePixmapFromData(XtDisplay(box),
 				    RootWindowOfScreen(XtScreen(box)),
