@@ -13,7 +13,7 @@
 /* |								       | */
 /* +-------------------------------------------------------------------+ */
 
-/* $Id: graphic.c,v 1.21 1996/09/27 06:17:31 torsten Exp $ */
+/* $Id: graphic.c,v 1.22 1997/09/03 19:31:07 torsten Exp $ */
 
 #include <X11/Intrinsic.h>
 #include <X11/Shell.h>
@@ -2008,15 +2008,15 @@ selectColorRange(Widget w, XtPointer wlArg, XtPointer junk)
 Widget
 makeGraphicShell(Widget wid)
 {
-    Arg args[2];
+    Arg args[6];
     int nargs = 0;
     Widget shell;
 
-    XtSetArg(args[nargs], XtNtitle, DEFAULT_TITLE);
-    nargs++;
-    XtSetArg(args[nargs], XtNiconName, DEFAULT_TITLE);
-    nargs++;
-
+    XtSetArg(args[nargs], XtNtitle, DEFAULT_TITLE); nargs++;
+    XtSetArg(args[nargs], XtNiconName, DEFAULT_TITLE); nargs++;
+    XtSetArg(args[nargs], XtNdepth, Global.vis.depth); nargs++;
+    XtSetArg(args[nargs], XtNvisual, Global.vis.visual); nargs++;
+    
     shell = XtAppCreateShell("Canvas", "Canvas",
 		   topLevelShellWidgetClass, XtDisplay(GetToplevel(wid)),
 			     args, nargs);
